@@ -85,10 +85,15 @@ class StartIE(GeneralBoolSettingToTrue):
     setting = 'START_IE'
     
 class StartSafari(GeneralBoolSettingToTrue):
-    """Start the Safari browser. Mac Only."""
+    """Start the Safari browser."""
     option_names = ('s', 'safari')
     setting = 'START_SAFARI'
     
+class StartChrome(GeneralBoolSettingToTrue):
+    """Start the Chrome browser. Windows Only."""
+    option_names = (None, 'chrome')
+    setting = 'START_CHROME'
+    
 # class RunPythonTests(object):
 #     """Run a set of python tests. 
 #         If no test file is specified the current directory is used."""
@@ -155,10 +160,10 @@ class Firebug(GeneralBoolSettingToTrue):
     option_names = (None, 'firebug')    
     setting = "INSTALL_FIREBUG"
     
-class NoCompress(GeneralBoolSettingToFalse):
+class NoCompress(GeneralBoolSettingToTrue):
     """Do not compress windmill javascript files."""
     option_names = (None, 'nocompress')
-    setting = "COMPRESS_JS"
+    setting = "DISABLE_JS_COMPRESS"
     
 class Port(object):
     """Set port for windmill to run. Default is 4444."""
