@@ -71,13 +71,13 @@ windmill.controller.asserts.assertRegistry = {
   },
 
   'assertNaN': {
-  expr: function (a) { return typeof a == 'undefined'; },
-  errMsg: 'expected to be undefined but was $1.'
+  expr: function (a) { return isNaN(a); },
+  errMsg: 'expected $1 to be NaN, but was not NaN.'
   },
 
   'assertNotNaN': {
-  expr: function (a) { return typeof a != 'undefined'; },
-  errMsg: 'expected not to be undefined but was undefined.'
+  expr: function (a) { return !isNaN(a); },
+  errMsg: 'expected $1 not to be NaN, but was NaN.'
   },
 
   'assertEvaluatesToTrue': {
@@ -103,117 +103,106 @@ windmill.controller.asserts.assertRegistry = {
 
 //Currently only does one level below the provided div
 //To make it more thorough it needs recursion to be implemented later
-windmill.controller.asserts.assertText = function (param_object) {
+windmill.controller.asserts.assertText = function (paramObject) {
 
-  var n = windmill.controller._lookupDispatch(param_object);
-  var validator = param_object.validator;
-  try{
-    if (n.innerHTML.indexOf(validator) != -1){
-      return true;
-    }
-    if (n.hasChildNodes()){
-      for(var m = n.firstChild; m != null; m = m.nextSibling) {
-	if (m.innerHTML.indexOf(validator) != -1){
-	  return true;
-	}
-	if (m.value.indexOf(validator) != -1){
-	  return true;
-	}
+  var n = lookupNode(paramObject);
+  var validator = paramObject.validator;
+  if (n.innerHTML.indexOf(validator) != -1){
+    return true;
+  }
+  if (n.hasChildNodes()){
+    for(var m = n.firstChild; m != null; m = m.nextSibling) {
+      //for non text nodes
+      if (m.nodeType != 3){
+        if (m.innerHTML.indexOf(validator) != -1){
+          return true;
+        }
+        if (m.value.indexOf(validator) != -1){
+          return true;
+        }
       }
     }
   }
-  catch(error){
-    return false;
-  }
-  return false;
+  throw "Text '"+validator+"' was not found in the provided node.";
 };
 
 //Assert that a specified node exists
-windmill.controller.asserts.assertNode = function (param_object) {
-  var element = windmill.controller._lookupDispatch(param_object);
-  if (!element){
-    return false;
-  }
-  return true;
+windmill.controller.asserts.assertNode = function (paramObject) {
+  var element = lookupNode(paramObject);
 };
 
 //Assert that a form element contains the expected value
-windmill.controller.asserts.assertValue = function (param_object) {
-  var n = windmill.controller._lookupDispatch(param_object);
-  var validator = param_object.validator;
+windmill.controller.asserts.assertValue = function (paramObject) {
+  var n = lookupNode(paramObject);
+  var validator = paramObject.validator;
 
-  if (n.value.indexOf(validator) != -1){
-    return true;
+  if (n.value.indexOf(validator) == -1){
+    throw "Value not found, \""+ n.value + "\" is not equal to \""+ validator+"\"";
   }
-  return false;
+  
 };
 
 //Assert that a provided value is selected in a select element
-windmill.controller.asserts.assertJS = function (param_object) {
-  var js = param_object.js;
+windmill.controller.asserts.assertJS = function (paramObject) {
+  var js = paramObject.js;
   var result = eval(js);
-  return result;
+  if (result != true){
+    throw "JavaScript did not return true."
+  }
 };
 
 //Asserting javascript with an element object available
-windmill.controller.asserts.assertElemJS = function (param_object) {
-  var element = windmill.controller._lookupDispatch(param_object);
-  if (!element){ return false; }
-  var js = param_object.js;
+windmill.controller.asserts.assertElemJS = function (paramObject) {
+  var element = lookupNode(paramObject);
+  var js = paramObject.js;
   var result = eval(js);
-  return result;
+  if (result != true){
+    throw "JavaScript did not return true."
+  }
 };
 
 //Assert that a provided value is selected in a select element
-windmill.controller.asserts.assertSelected = function (param_object) {
-  var n = windmill.controller._lookupDispatch(param_object);
-  var validator = param_object.validator;
+windmill.controller.asserts.assertSelected = function (paramObject) {
+  var n = lookupNode(paramObject);
+  var validator = paramObject.validator;
 
-  if (n.options[n.selectedIndex].value == validator){
-    return true;
+  if ((n.options[n.selectedIndex].value != validator) && (n.options[n.selectedIndex].innerHTML != validator)){
+    throw "Not selected, "+n.options[n.selectedIndex].value+" is not equal to " + validator;
   }
-  return false;
 };
 
 //Assert that a provided checkbox is checked
-windmill.controller.asserts.assertChecked = function (param_object) {
-  var n = windmill.controller._lookupDispatch(param_object);
+windmill.controller.asserts.assertChecked = function (paramObject) {
+  var n = lookupNode(paramObject);
 
-  if (n.checked == true){
-    return true;
+  if (!n.checked){
+    throw "Checked property not true";
   }
-  return false;
 };
 
 // Assert that a an element's property is a particular value
-windmill.controller.asserts.assertProperty = function (param_object) {
-  var element = windmill.controller._lookupDispatch(param_object);
-  if (!element){
-    return false;
-  }
-  var vArray = param_object.validator.split('|');
+windmill.controller.asserts.assertProperty = function (paramObject) {
+  var element = lookupNode(paramObject);
+  var vArray = paramObject.validator.split('|');
   var value = eval ('element.' + vArray[0]+';');
-  var res = false;
-  try {
-    if (value.indexOf(vArray[1]) != -1){
-      res = true;
-    }
-  }
-  catch(err){
+  
+  if (value.indexOf(vArray[1]) != -1){
+    return true;
   }
   if (String(value) == String(vArray[1])) {
-    res = true;
+    return true;
   }
-  return res;
+  
+  throw "Property did not match."
 };
 
 // Assert that a specified image has actually loaded
 // The Safari workaround results in additional requests
 // for broken images (in Safari only) but works reliably
-windmill.controller.asserts.assertImageLoaded = function (param_object) {
-  var img = windmill.controller._lookupDispatch(param_object);
+windmill.controller.asserts.assertImageLoaded = function (paramObject) {
+  var img = lookupNode(paramObject);
   if (!img || img.tagName != 'IMG') {
-    return false;
+    throw "The node was not an image."
   }
   var comp = img.complete;
   var ret = null; // Return value
@@ -234,12 +223,12 @@ windmill.controller.asserts.assertImageLoaded = function (param_object) {
   // False -- Img failed to load in IE/Safari, or is
   // still trying to load in FF
   if (comp === false) {
-    ret = false;
+    throw "Image complete attrib false."
   }
   // True, but image has no size -- image failed to
   // load in FF
   else if (comp === true && img.naturalWidth == 0) {
-    ret = false;
+    throw "Image has no size, failure to load."
   }
   // Otherwise all we can do is assume everything's
   // hunky-dory
@@ -260,10 +249,13 @@ windmill.controller.asserts._AssertFactory = new function () {
   function createErrMsg(msg, arr) {
     var str = msg;
     for (var i = 0; i < arr.length; i++) {
-      var val = arr[i];
-      var display = '<' + val.toString().replace(/\n/g, '') +
-        '> (' + getTypeDetails(val) + ')';
-      str = str.replace('$' + (i + 1).toString(), display);
+      //When calling jum functions arr is an array with a null entry
+      if (arr[i] != null){
+        var val = arr[i];
+        var display = '<' + val.toString().replace(/\n/g, '') +
+          '> (' + getTypeDetails(val) + ')';
+        str = str.replace('$' + (i + 1).toString(), display);
+      }
     }
     return str;
   }
@@ -308,8 +300,9 @@ windmill.controller.asserts._AssertFactory = new function () {
 	      return true;
       }
       else {
-	      var message = meth + ' -- ' +
+        var message = meth + ' -- ' +        
         createErrMsg(asrt.errMsg, args);
+        
 	      throw new windmill.controller.asserts._WindmillAssertException(comment, message);
       }
     };
