@@ -21,9 +21,8 @@ windmill.controller.what = function() {
 }
 
 //Click function for Mozilla with Chrome
-windmill.controller.click = function(param_object){
-    var element = this._lookupDispatch(param_object);
-    if (!element){ return false; }
+windmill.controller.click = function(paramObject){
+    var element = lookupNode(paramObject);
     windmill.events.triggerEvent(element, 'focus', false);
 
     // Add an event listener that detects if the default action has been prevented.
@@ -36,12 +35,26 @@ windmill.controller.click = function(param_object){
     element.addEventListener('click', function(evt) {
         savedEvent = evt;
     }, false);
-
+    
     // Trigger the event.
     windmill.events.triggerMouseEvent(element, 'mousedown', true);
     windmill.events.triggerMouseEvent(element, 'mouseup', true);
-    windmill.events.triggerMouseEvent(element, 'click', true);
-    try{
+    
+    //if click options are attached for keyboard keys
+    if (paramObject.options){
+      var arr = paramObject.options.split(',');
+      arr.unshift(element, 'click', true, null, null);
+      windmill.events.triggerMouseEvent.apply(this, arr);
+    }
+    else { windmill.events.triggerMouseEvent(element, 'click', true); }
+
+    try {
+      //if there is an element.onclick function defined, the likelyhood
+      //is that the user doesn't want to open that elements href
+      if (typeof element.onclick == "function"){
+        return;
+      }
+      
       // Perform the link action if preventDefault was set.
       // In chrome URL, the link action is already executed by triggerMouseEvent.
       if (!browser.isChrome && savedEvent != null && !savedEvent.getPreventDefault()) {
@@ -61,49 +74,31 @@ windmill.controller.click = function(param_object){
       }
     }
     catch(err){}
-  return true;    
 };
 
 //there is a problem with checking via click in safari
-windmill.controller.check = function(param_object){
-  return windmill.controller.click(param_object);    
-}
+windmill.controller.check = function(paramObject){
+  return windmill.controller.click(paramObject);    
+};
 
 //Radio buttons are even WIERDER in safari, not breaking in FF
-windmill.controller.radio = function(param_object){
-  return windmill.controller.click(param_object);      
-}
+windmill.controller.radio = function(paramObject){
+  return windmill.controller.click(paramObject);      
+};
 
 //Double click for Mozilla
-windmill.controller.doubleClick = function(param_object) {
-
+windmill.controller.doubleClick = function(paramObject) {
  //Look up the dom element, return false if its not there so we can report failure
- var element = this._lookupDispatch(param_object);
- if (!element){
-    return false;
- }
-    
+ var element = lookupNode(paramObject);
  windmill.events.triggerEvent(element, 'focus', false);
-
- // Trigger the mouse event.
  windmill.events.triggerMouseEvent(element, 'dblclick', true);
-
- /*if (this._windowClosed()) {
-     return;
- }*/
-
  windmill.events.triggerEvent(element, 'blur', false);
- 
- return true;
 };
 
 //Type Function
- windmill.controller.type = function (param_object){
+ windmill.controller.type = function (paramObject){
+   var element = lookupNode(paramObject);
 
-   var element = this._lookupDispatch(param_object);
-   if (!element){
-     return false;
-   }
    //clear the box
    element.value = '';
    //Get the focus on to the item to be typed in, or selected
@@ -112,8 +107,8 @@ windmill.controller.doubleClick = function(param_object) {
     
    //Make sure text fits in the textbox
    var maxLengthAttr = element.getAttribute("maxLength");
-   var actualValue = param_object.text;
-   var stringValue = param_object.text;
+   var actualValue = paramObject.text;
+   var stringValue = paramObject.text;
     
    if (maxLengthAttr != null) {
      var maxLength = parseInt(maxLengthAttr);
@@ -133,13 +128,11 @@ windmill.controller.doubleClick = function(param_object) {
      windmill.events.triggerKeyEvent(element, 'keyup', s.charAt(c), true, false,false, false,false);
    }
    //if for some reason the key events don't do the typing
-   if (element.value == ""){
+   if (element.value != s){
      element.value = s;
    }
     
    // DGF this used to be skipped in chrome URLs, but no longer.  Is xpcnativewrappers to blame?
    //Another wierd chrome thing?
    windmill.events.triggerEvent(element, 'change', true);
-    
-   return true;
  };
\ No newline at end of file
