@@ -19,19 +19,145 @@ if (!opener) {
     document.location = '/windmill-serv/start.html';
 }
 
-//json_call
-var json_call = function(version, method, params) {
+//jsonCall
+var jsonCall = function(version, method, params) {
     this.version = version || null;
     this.method = method || null;
     this.params = params || [];
 };
 
+
+//Translates from the way we are passing objects to functions to the lookups
+var lookupNode = function (paramObject, throwErr){
+  if (typeof(throwErr) == "undefined"){
+    var throwErr = false;
+  }
+  
+  var s = null;
+  var element = null;
+  //If a link was passed, lookup as link
+  if(typeof paramObject.link != "undefined") {
+    s = 'Looking up link '+ paramObject.link;
+    element = elementslib.Element.LINK(paramObject.link);
+  }
+  //if xpath was passed, lookup as xpath
+  if(typeof paramObject.xpath != "undefined") {
+    s = 'Looking up xpath '+ paramObject.xpath;        
+    element = elementslib.Element.XPATH(paramObject.xpath);
+  }
+  //if id was passed, do as such
+  if(typeof paramObject.id != "undefined") {
+    s = 'Looking up id '+ paramObject.id;
+    element = elementslib.Element.ID(paramObject.id);
+  }
+  //if jsid was passed
+  if(typeof paramObject.jsid != "undefined") {
+    //Here if the user hasn't specified the test window scope
+    //we use the default and prepend it, else we eval whatever js they passed
+    var jsid; 
+    if ((paramObject.jsid.indexOf('windmill.testWindow') != -1) || (paramObject.jsid.indexOf('_w') != -1)){
+      eval ("jsid=" + paramObject.jsid + ";");
+    }
+    else{
+      eval ("jsid=" + this._getWindowStr() + '.' +paramObject.jsid + ";");
+    }
+      s = 'Looking up jsid '+ jsid;
+      element = elementslib.Element.ID(paramObject.id);
+  }
+  //if name was passed
+  if(typeof paramObject.name != "undefined") {
+    s = 'Looking up name '+ paramObject.name;
+    element = elementslib.Element.NAME(paramObject.name);
+  }
+  //if name was passed
+  if(typeof paramObject.value != "undefined") {
+    s = 'Looking up value '+ unescape(paramObject.value);
+    element = elementslib.Element.VALUE(paramObject.value);
+  }
+  //if name was passed
+  if(typeof paramObject.classname != "undefined") {
+    s = 'Looking up classname '+ paramObject.classname;
+    element = elementslib.Element.CLASSNAME(paramObject.classname);
+  }
+  //if name was passed
+  if(typeof paramObject.tagname != "undefined") {
+    s = 'Looking up tagname '+ paramObject.tagname;
+    element = elementslib.Element.TAGNAME(paramObject.tagname);
+  }
+  //if name was passed
+  if(typeof paramObject.label != "undefined") {
+    s = 'Looking up label '+ paramObject.label;
+    element = elementslib.Element.LABEL(paramObject.label);
+  }
+  //scroll so that the element is in view
+  if (element) { 
+    //if the element you accessed is a flash object
+    //the scroll into view will actually fail and 
+    //throw a crazy DOM exception
+    try {
+      element.scrollIntoView(); 
+    } catch(err){}
+    
+    return element;
+  }
+  else if (throwErr == true) { throw s + ", failed."; }
+  else{ lookupNode(paramObject, true); }
+};
+
+//Function to handle the random keyword scenario
+var handleVariable = function (val){
+  var ret = val;
+  var matches = val.match(/{\$[^}]*}/g);
+  if (matches) {
+    for (var i = 0; i < matches.length; i++){
+      var m = matches[i];
+      if (windmill.varRegistry.hasKey(m)){
+        ret = windmill.helpers.replaceAll(val, m, windmill.varRegistry.getByKey(m));
+      }
+      //if it doesn't exist and contains the string random we create it (username or pass etc)
+      else if (m.indexOf('random') != -1){
+        ret = val.replace(m, windmill.varRegistry.addItemCreateValue(m));
+      }
+    }
+  }
+  return ret;
+};
+
+var sendCommandResult = function(status, uuid, result){
+  //Send to the server
+	var jsonObject = new jsonCall('1.1', 'command_result');
+	var params_obj = {"status":status, "uuid":uuid, "result":result};
+	jsonObject.params = params_obj;
+	var jsonString = fleegix.json.serialize(jsonObject)
+
+	var resp = function(str){ return true; }
+    
+	result = fleegix.xhr.doPost('/windmill-jsonrpc/', jsonString);
+	resp(result);
+}
+
 var busyOn = function(){
+  //Centering the message on the screen
+  var load = document.getElementById('statusMessage');
+  load.style.position = 'absolute';
+  load.style.display = 'block';
+  load.style.left = "";
+  load.style.top = "";
+  fleegix.dom.center(load);
+  var left = load.style.left.replace("px", "");
+  var top = load.style.top.replace("px", "");
+  var leftInt = left - 60;
+  var topInt = top - 40;
+  load.style.left = leftInt+"px";
+  load.style.top = topInt+"px";
+
+  //Show it
   $('actionDD').style.visibility = "hidden";
   $('cover').style.display = "block";
 }
 var busyOff = function(){
-  jQuery("#loadMessage").html("Please wait, (Doing Stuff)...");        
+
+  jQuery("#loadMessage").html("Please wait...");
   $('actionDD').style.visibility = "visible";
   $('cover').style.display = "none";
 }
@@ -50,20 +176,7 @@ var openSettings = function() {
     windmill.ui.assertexplorer.assertExplorerOff();
 
     //$(id).style.display = 'block';
-    jQuery("#dialog").dialog({
-      height: 450,
-      width: 400,
-      modal:true,
-      overlay: { 
-          opacity: 0.5, 
-          background: "black" 
-      },
-      buttons: { 
-       "Ok": function() { 
-           jQuery(this).dialog("close"); 
-       } 
-      }
-    });
+    jQuery("#dialog").dialog('open');
     // $('ide').style.display = 'none';
     // $('actionDD').style.visibility = "hidden";
 };
@@ -71,20 +184,35 @@ var openSettings = function() {
 var openFirebug = function(){
   firebug.init();
   firebug.win.minimize();
-  //if firebug has already been injected into the app
-  if (!opener.firebug){
-    var piScript = opener.document.createElement('script');
-    piScript.src = "windmill-serv/js/lib/pi.js"
-    var fbScript = opener.document.createElement('script');
-    fbScript.src = "windmill-serv/js/lib/firebug-lite.js";
-    opener.document.body.insertBefore(piScript, opener.document.body.childNodes[0]);
-    opener.document.body.insertBefore(fbScript, opener.document.body.childNodes[0]);
-    setTimeout('opener.firebug.init();opener.firebug.win.maximize()', 1000);
-  }
-  else{
-    opener.firebug.init();
-    opener.firebug.win.maximize();
+  
+  //For some reason if you don't do this in IE
+  //you can't see the firebug window in the IDE
+  if (windmill.browser.isIE){
+    $('tabs').style.height = "90%";
   }
+  
+  try {
+    //if firebug has already been injected into the app
+    if (!windmill.testWin().firebug){
+    	var fbCSS = windmill.testWin().document.createElement('link');
+    	fbCSS.rel = "stylesheet";
+    	fbCSS.type = "text/css";
+    	fbCSS.href = "/windmill-serv/css/firebug-lite.css";
+    	windmill.testWin().document.body.insertBefore(fbCSS, windmill.testWin().document.body.childNodes[0]);
+  	
+      var piScript = windmill.testWin().document.createElement('script');
+      piScript.src = "/windmill-serv/js/lib/firebug/pi.js"
+      var fbScript = windmill.testWin().document.createElement('script');
+      fbScript.src = "/windmill-serv/js/lib/firebug/firebug-lite.js";
+      windmill.testWin().document.body.insertBefore(piScript, windmill.testWin().document.body.childNodes[0]);
+      windmill.testWin().document.body.insertBefore(fbScript, windmill.testWin().document.body.childNodes[0]);
+      setTimeout('try { windmill.testWin().firebug.init();windmill.testWin().firebug.win.maximize(); } catch(err){} ', 1000);
+    }
+    else{
+      windmill.testWin().firebug.init();
+      windmill.testWin().firebug.win.maximize();
+    }
+  } catch(err){ windmill.err("Could not add firebug lite to the test app, as it wasn't available, try again."); }
 }
 
 var resetDD = function(){
@@ -96,7 +224,7 @@ var toggleRec = function() {
         windmill.ui.domexplorer.domExplorerOff();
         windmill.ui.assertexplorer.assertExplorerOff();
         windmill.ui.recorder.recordOn();
-        opener.window.focus();
+        windmill.testWin().focus();
         $('record').src = 'img/stoprecord.png';
     }
     else {
@@ -107,8 +235,8 @@ var toggleRec = function() {
 }
 var togglePlay = function() {
     if ($('playback').src.indexOf("img/playback.png") != -1) {
-        windmill.ui.results.writeStatus("Playing IDE Actions...");
-        windmill.controller.continueLoop();
+        windmill.stat("Playing IDE Actions...");
+        windmill.continueLoop();
         windmill.ui.playback.sendPlayBack();
         $('playback').src = 'img/playbackstop.png';
 
@@ -123,11 +251,11 @@ var togglePlay = function() {
 var toggleLoop = function() {
     if ($('loopLink').innerHTML.indexOf('Pause') != -1) {
         $('loopLink').innerHTML = 'Resume Service Loop';
-        windmill.controller.stopLoop();
+        windmill.pauseLoop();
     }
     else {
         $('loopLink').innerHTML = 'Pause Service Loop';
-        windmill.controller.continueLoop();
+        windmill.continueLoop();
     }
 
 }
@@ -139,7 +267,7 @@ var toggleExplore = function() {
         $('domExp').style.visibility = 'visible';
         $('domExp').innerHTML = '';
         windmill.ui.domexplorer.domExplorerOn();
-        opener.window.focus();
+        windmill.testWin().focus();
         $('explorer').src = 'img/xoff.png';
     }
     else {
@@ -158,7 +286,7 @@ var toggleAExplore = function() {
         $('domExp').style.visibility = 'visible';
         $('domExp').innerHTML = '';
         windmill.ui.assertexplorer.assertExplorerOn();
-        opener.window.focus();
+        windmill.testWin().focus();
         $('assertx').src = 'img/axoff.png';
     }
     else {
@@ -178,7 +306,7 @@ var scroll = function() {
     //However if they scroll back to the bottom, we want to turn auto scroll on
     $('autoScroll').checked = false;
 
-    var ide = $('ide');
+    var ide = $('ideForm');
     var a = ide.scrollTop;
     var b = ide.scrollHeight - ide.offsetHeight + 1;
     var c = a - b;
@@ -188,15 +316,30 @@ var scroll = function() {
     if (Math.abs(c) < 4) { $('autoScroll').checked = true; }
     //If not we keep auto scroll off
     else { $('autoScroll').checked = false; }
-}
+};
 
 var doSubmit = function() {
     return false;
-}
+};
 
+var dumpOutput = function(){
+  for (var i = 0; i < windmill.errorArr.length; i++){
+    windmill.out(windmill.errorArr[i]);
+  }
+  jQuery("#dialog").dialog('close');
+  jQuery('#tabs').tabs("select", 1);
+};
 
 var $ = function(id) {
-		  return document.getElementById(id);
+	return document.getElementById(id);
+};
+
+var copyObj = function(obj){
+   var n = new Object;
+   for (i in obj){
+      n[i] = obj[i];
+    }
+  return n;
 };
 
 var PatternMatcher = function(pattern) {
@@ -279,11 +422,23 @@ windmill.helpers.normalizeSpaces = function(text)
     }
 }
 
-windmill.helpers.replaceAll = function(text, oldText, newText) {
-    while (text.indexOf(oldText) != -1) {
-	text = text.replace(oldText, newText);
-    }
-    return text;
+// windmill.helpers.replaceAll = function(text, oldText, newText) {
+//     while (text.indexOf(oldText) != -1) {
+//      text = text.replace(oldText, newText);
+//     }
+//     return text;
+// }
+
+windmill.helpers.replaceAll = function (OldString, FindString, ReplaceString) {
+  var SearchIndex = 0;
+  var NewString = ""; 
+  while (OldString.indexOf(FindString,SearchIndex) != -1)    {
+    NewString += OldString.substring(SearchIndex,OldString.indexOf(FindString,SearchIndex));
+    NewString += ReplaceString;
+    SearchIndex = (OldString.indexOf(FindString,SearchIndex) + FindString.length);         
+  }
+  NewString += OldString.substring(SearchIndex,OldString.length);
+  return NewString;
 }
 
 /**
@@ -439,7 +594,7 @@ function AssertionFailedError(message) {
 //JSUtils
 var parseString = function(str, s){
   var arr = str.split('.');
-  var win = windmill.testWindow;
+  var win = windmill.testWin();
   if (s){ win = s;}
       
   var parseRecurse = function (n) {
@@ -456,4 +611,4 @@ function removeHTMLTags(str){
  		var strTagStrippedText = str.replace(/<\/?[^>]+(>|$)/g, "");
  		strTagStrippedText = strTagStrippedText.replace(/&nbsp;/g,"");
 	return strTagStrippedText;
-}
+}
\ No newline at end of file
