@@ -28,8 +28,17 @@ windmill.ui = new function() {
     //global settings for highlight color for explorers
     this.borderHilight = '1px solid #003366';
     
+    //variable to decide whether to use outline or border
+     if (windmill.browser.isIE){
+       this.hilightProp = "border";
+     }
+     else {
+       this.hilightProp = "outline";
+     }
+     
     //keeping track of the recorder state when a new page is loaded and wipes the document
     this.recordSuiteNum = 0;
+    this.currentSuite = null;
     
     //Setter, incremeneting the recordSuiteNum
     this.incRecSuite = function() {
@@ -39,9 +48,11 @@ windmill.ui = new function() {
     this.toggleCollapse = function(id) {
         if ($(id).style.height == '22px') {
             $(id).style.height = '';
+            $(id).style.borderBottom = "";
         }
         else {
             $(id).style.height = '22px';
+            $(id).style.borderBottom = "1px solid #aaa";
         }
     };
 
@@ -55,6 +66,19 @@ windmill.ui = new function() {
             windmill.stopOnFailure = false;
         }
     }
+    
+    this.updateAlerts = function(){
+      if ($('jsAlerts').checked){
+        windmill.alerts = true;
+      }
+      else {
+        windmill.alerts = false;
+        try {
+          windmill.testWin().alert = windmill.testWin().oldAlert;
+        } catch(err){ windmill.err(err); }
+      }
+    }
+    
     this.getContMethodsUI = function() {
         var str = '';
         for (var i in windmill.controller) {
@@ -131,7 +155,6 @@ windmill.ui.playback = new function() {
         suites.push($(suiteOnly));
         $(suiteOnly).style.border = "0px";
         $(suiteOnly).style.borderBottom = '1px solid black';
-        
       }
 
       //else play every suite in the IDE
@@ -161,7 +184,7 @@ windmill.ui.playback = new function() {
                       //If it wasn't a standard UI element
                       if ($(suites[i].childNodes[j].id + 'params') != null) {
                           actionObj.method = $(suites[i].childNodes[j].id + 'method').value;
-                          actionObj.params = eval('(' + $(suites[i].childNodes[j].id + 'params').value + ')');
+                          actionObj.params = eval('(' + escape($(suites[i].childNodes[j].id + 'params').value) + ')');
 
                       }
                       //if its a standard UI element build the params
@@ -174,12 +197,12 @@ windmill.ui.playback = new function() {
 
                           if (windmill.registry.methods[actionObj.method].locator) {
                               var si = $(suites[i].childNodes[j].id + 'locatorType').selectedIndex;
-                              paramsObj[$(suites[i].childNodes[j].id + 'locatorType')[si].value] = $(suites[i].childNodes[j].id + 'locator').value;
+                              paramsObj[$(suites[i].childNodes[j].id + 'locatorType')[si].value] = escape($(suites[i].childNodes[j].id + 'locator').value);
 
                           }
                           if (windmill.registry.methods[actionObj.method].option) {
                               var si = $(suites[i].childNodes[j].id + 'optionType').selectedIndex;
-                              paramsObj[$(suites[i].childNodes[j].id + 'optionType')[si].value] = $(suites[i].childNodes[j].id + 'option').value;
+                              paramsObj[$(suites[i].childNodes[j].id + 'optionType')[si].value] = escape($(suites[i].childNodes[j].id + 'option').value);
                           }
 
                           actionObj.params = paramsObj;
@@ -214,14 +237,16 @@ windmill.ui.playback = new function() {
           return true;
       }
 
-      var json_object = new json_call('1.1', 'restart_test_run');
+      var jsonObject = new jsonCall('1.1', 'restart_test_run');
       var params_obj = {};
       params_obj.tests = testArray;
-      json_object.params = params_obj;
-      var json_string = fleegix.json.serialize(json_object)
-
+      jsonObject.params = params_obj;
+      
+      //Serialize
+      var jsonString = fleegix.json.serialize(jsonObject);
+      
       doCall = function() {
-          var z = fleegix.xhr.doPost(respRun, '/windmill-jsonrpc/', json_string);
+        var z = fleegix.xhr.doPost(respRun, '/windmill-jsonrpc/', jsonString);
       }
 
       setTimeout('doCall()', 100);
